#include <Wire.h>
#include <ESP8266WiFi.h>
#include <Adafruit_Sensor.h>
#include <Adafruit_BME280.h>

/*#include <SPI.h>
#define BME_SCK 18
#define BME_MISO 19
#define BME_MOSI 23
#define BME_CS 5*/

Adafruit_BME280 bme; // I2C
//Adafruit_BME280 bme(BME_CS); // hardware SPI
//Adafruit_BME280 bme(BME_CS, BME_MOSI, BME_MISO, BME_SCK); // software SPI

float h, t, p, pin, dp;
char temperatureString[6];
char dpString[6];
char humidityString[6];
char pressureString[7];
char pressureInchString[6];
unsigned long delayTime;

// replace with you First Channel ThingSpeak Write API key
String apiKey = "111111111ANK1B0";
// replace with your local network SSID
const char* ssid = "TR-2";
// replace with your local network password
const char* password = "1234";
const char* server = "api.thingspeak.com";

WiFiClient client;

// only runs once on boot
void setup() {
  // Initializing serial port for debugging purposes
   Serial.begin(115200);
  delay(10);
  Wire.begin(D3, D4); // Make sure you have D3(SDA) & D4 (SCL) hooked up to the BME280 SENSOR
  Wire.setClock(100000);
  // Connecting to WiFi network
  Serial.println();
  Serial.print("Connecting to ");
  Serial.println(ssid);
  
  WiFi.begin(ssid, password);
  
  while (WiFi.status() != WL_CONNECTED) {
    delay(500);
    Serial.print(".");
  }
  Serial.println("");
  Serial.println("WiFi connected");
  
    // Printing the ESP IP address
  Serial.println(WiFi.localIP());

  if (!bme.begin()) {
    Serial.println("Could not find a valid BME280 sensor, check wiring!");
    while (1);
  }
}

void loop() {
    h = bme.readHumidity();
    t = bme.readTemperature();//temperature in Celcius
    //t = t*1.8+32.0; //uncomment if you want to get temperature in Fahrenheit
    dp = t-0.36*(100.0-h);
    
    p = bme.readPressure()/100.0F;
    pin = 0.02953*p;
    dtostrf(t, 5, 1, temperatureString);
    dtostrf(h, 5, 1, humidityString);
    dtostrf(p, 6, 1, pressureString);
    dtostrf(pin, 5, 2, pressureInchString);
    dtostrf(dp, 5, 1, dpString);
    delay(10000);

    Serial.print("Temperature = ");
    Serial.println(temperatureString);
    Serial.print("Humidity = ");
    Serial.println(humidityString);
    Serial.print("Pressure = ");
    Serial.println(pressureString);
    Serial.print("Pressure Inch = ");
    Serial.println(pressureInchString);
    Serial.print("Dew Point = ");
    Serial.println(dpString);
    
    if (client.connect(server,80))  // "184.106.153.149" or api.thingspeak.com
    {
        String postStr = apiKey;
        postStr +="&field1=";
        postStr += String(temperatureString);
        postStr +="&field2=";
        postStr += String(humidityString);
        postStr +="&field3=";
        postStr += String(pressureString);
        //postStr += String(pressureInchString);//uncomment if you need pressure in inch
        postStr += "\r\n\r\n";
        
        client.print("POST /update HTTP/1.1\n");
        client.print("Host: api.thingspeak.com\n");
        client.print("Connection: close\n");
        client.print("X-THINGSPEAKAPIKEY: "+apiKey+"\n");
        client.print("Content-Type: application/x-www-form-urlencoded\n");
        client.print("Content-Length: ");
        client.print(postStr.length());
        client.print("\n\n");
        client.print(postStr);    
    }
    client.stop(); 
    //every 30 seconds   
    delay(30000);
}
